==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebDensityChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebDensityChangedEventArgsDetailDescription } from "./WebDensityChangedEventArgsDetailDescription";
/**
 * @hidden
 */
var WebDensityChangedEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDensityChangedEventArgsDetailDescriptionMetadata, _super);
    function WebDensityChangedEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDensityChangedEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebDensityChangedEventArgsDetailDescriptionMetadata.a == null) {
            WebDensityChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDensityChangedEventArgsDetailDescriptionMetadata.c(WebDensityChangedEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebDensityChangedEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDensityChangedEventArgsDetailDescriptionMetadata.a);
    };
    WebDensityChangedEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:DensityChangedEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("OldDensity", "ExportedType:string:DisplayDensity");
        a.item("OldDensity@names", "Comfortable;Cosy;Compact");
        a.item("NewDensity", "ExportedType:string:DisplayDensity");
        a.item("NewDensity@names", "Comfortable;Cosy;Compact");
    };
    WebDensityChangedEventArgsDetailDescriptionMetadata.d = function (a) {
        WebDensityChangedEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebDensityChangedEventArgsDetail", function () { return new WebDensityChangedEventArgsDetailDescription(); });
        a.z("WebDensityChangedEventArgsDetail", WebDensityChangedEventArgsDetailDescriptionMetadata.a);
    };
    WebDensityChangedEventArgsDetailDescriptionMetadata.$t = markType(WebDensityChangedEventArgsDetailDescriptionMetadata, 'WebDensityChangedEventArgsDetailDescriptionMetadata');
    WebDensityChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebDensityChangedEventArgsDetailDescriptionMetadata;
}(Base));
export { WebDensityChangedEventArgsDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebDensityChangedEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebDensityChangedEventArgsDetailDescription } from "./WebDensityChangedEventArgsDetailDescription";
/**
 * @hidden
 */
var WebDensityChangedEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDensityChangedEventArgsDetailDescriptionMetadata, _super);
    function WebDensityChangedEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDensityChangedEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebDensityChangedEventArgsDetailDescriptionMetadata.a == null) {
            WebDensityChangedEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDensityChangedEventArgsDetailDescriptionMetadata.c(WebDensityChangedEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebDensityChangedEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebDensityChangedEventArgsDetailDescriptionMetadata.a);
    };
    WebDensityChangedEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:DensityChangedEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("OldDensity", "ExportedType:string:DisplayDensity");
        a.item("OldDensity@stringUnion", "WebComponents;React");
        a.item("OldDensity@names", "Comfortable;Cosy;Compact");
        a.item("NewDensity", "ExportedType:string:DisplayDensity");
        a.item("NewDensity@stringUnion", "WebComponents;React");
        a.item("NewDensity@names", "Comfortable;Cosy;Compact");
    };
    WebDensityChangedEventArgsDetailDescriptionMetadata.d = function (a) {
        WebDensityChangedEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebDensityChangedEventArgsDetail", function () { return new WebDensityChangedEventArgsDetailDescription(); });
        a.ab("WebDensityChangedEventArgsDetail", WebDensityChangedEventArgsDetailDescriptionMetadata.a);
    };
    WebDensityChangedEventArgsDetailDescriptionMetadata.$t = markType(WebDensityChangedEventArgsDetailDescriptionMetadata, 'WebDensityChangedEventArgsDetailDescriptionMetadata');
    WebDensityChangedEventArgsDetailDescriptionMetadata.a = null;
    return WebDensityChangedEventArgsDetailDescriptionMetadata;
}(Base));
export { WebDensityChangedEventArgsDetailDescriptionMetadata };
